This function returns a data frame of spectral indices, from the
awesome-spectral-indices repository.
spectral_indices(
...,
url = spectral_indices_url(),
download_indices = NULL,
update_cache = NULL
)A tibble::tibble with nine columns, containing information about spectral indices.
These dots are for future extensions and must be empty.
The URL to download spectral indices from. If the option rsi_url
is set, that value will be used; otherwise, if the environment variable
rsi_url is set, that value will be used; otherwise, the list at
https://github.com/awesome-spectral-indices/awesome-spectral-indices will
be used.
Logical: should this function download indices? If
NULL, this function will only download indices if the cache will be
updated. If TRUE, this function will attempt to download indices no matter
what. If FALSE, either cached or package indices will be used.
Logical: should cached indices be updated? If NULL,
cached values will be updated if the cache is older than a day. If TRUE,
the cache will be updated, if FALSE it will not.